@@ -788,7 +788,7 @@ void IrcContextMenus::setupTopicHistoryMenu()
 
     m_topicHistoryMenu->addAction(m_textCopyAction);
 
-    m_queryTopicAuthorAction = createAction(m_topicHistoryMenu, OpenQuery, i18nc("Opens a query (private message) window with the author of the topic", "Query author"));
+    m_queryTopicAuthorAction = createAction(m_topicHistoryMenu, OpenQuery, i18n("Query author"));
 }
 
 void IrcContextMenus::topicHistoryMenu(const QPoint& pos, Server* server, const QString& text, const QString& author)
@@ -897,3 +897,5 @@ void IrcContextMenus::commandToServer(Server* server, const QString& command,
     for (const QString& argument : arguments)
         commandToServer(server, command.arg(argument), destination);
 }
+
+#include "moc_irccontextmenus.cpp"
